import redis

class RedisConnect(object):

    @classmethod
    def __init__(self, host, port, db):

        if hasattr(self,'redis_pool') is False:
            self.redis_pool = redis.ConnectionPool(
                host=host, port=port, db=db,
                max_connections=25)
            self.server = redis.StrictRedis(connection_pool=self.redis_pool)
        else:
            pass

    def get(self, key):
        return self.server.get(key)

    def set(self, key, value):
        return self.server.set(key, value)

    def setex(self, key, ttl, value):
        return self.server.setex(key, ttl, value)

    def getset(self, key, value):
        return self.server.getset(key, value)

    def expire(self, key, value):
        return self.server.expire(key, value)

    def exists(self, key):
        return self.server.exists(key)


from li_common.helpers import tente_outra_vez

from pyelasticsearch import ElasticSearch
from requests import ConnectionError

# Existe apenas para repasse de exceptions via heranca
from pyelasticsearch import exceptions as ElasticsearchExceptions

class ElasticsearchConnect(object):
    def __init__(self,elasticsearch_url):
        self.server = ElasticSearch(elasticsearch_url)

    def search(self, query, **kwargs):
        return self.server.search(query, **kwargs)

    @tente_outra_vez(ConnectionError, tentativas=4, tempo_espera=3, multiplicador_espera=2)
    def index(self, index, content_type, content):
        return self.server.index(index, content_type, content)

    def bulk_index(self, index, doc_type, docs, **kwargs):
        return self.server.bulk_index(index, doc_type, docs, **kwargs)

    def delete_by_query(self, index, doc_type, query, **kwargs):
        return self.server.delete_by_query(index, doc_type, query, **kwargs)

    def delete(self, index, doc_type, id, **kwargs):
        return self.server.delete(index, doc_type, id, **kwargs)


# -*- coding: utf-8 -*-

import base64
from Crypto.Cipher import Blowfish

# Funcao para encriptar de drcriptogravar dados
class Criptografia(object):
    def __init__(self, secret_key, id, salt):
        secret_key = secret_key[:11] + secret_key[-12:]
        id = str(id).ljust(10, 'x')
        salt = salt[:23]
        self.chave = '%s%s%s' % (secret_key, id, salt)

    def encriptar(self, string):
        """Encripta um código qualquer usando uma chave dinâmica."""
        encryption_object = Blowfish.new(self.chave)
        padding = ''
        if (len(string) % 8) != 0:
            padding = 'x' * (8 - (len(string) % 8))
        return base64.b64encode(encryption_object.encrypt(string + padding))

    def decriptar(self, string):
        """Decripta um código qualquer usando uma chave dinâmica."""
        encryption_object = Blowfish.new(self.chave)
        return encryption_object.decrypt(base64.b64decode(string)).rstrip('x')